#
# spec file for package eric
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2010-2022 LISA GmbH, Bingen, Germany
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define distname eric6

Name:           eric
Version:        21.11
Release:        2.6
Summary:        Python IDE based on Qt5
License:        GPL-3.0-or-later
Group:          Development/Tools/IDE
URL:            https://eric-ide.python-projects.org/
Source:         https://sourceforge.net/projects/eric-ide/files/%{distname}/stable/%{version}/%{distname}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  python-rpm-macros
BuildRequires:  python3-EditorConfig
BuildRequires:  python3-qscintilla-qt5
BuildRequires:  python3-qt5
BuildRequires:  python3-qtcharts-qt5
BuildRequires:  python3-qtwebengine-qt5
BuildRequires:  python3-xml
BuildRequires:  update-desktop-files
Requires:       libQt5Sql5-sqlite
Requires:       python3-EditorConfig
Requires:       python3-qscintilla-qt5
Requires:       python3-qt5
Requires:       python3-qtcharts-qt5
Requires:       python3-qtwebengine-qt5
Requires:       python3-xml
Recommends:     %{name}-api = %{version}
Recommends:     libQt5Sql5-mysql
Recommends:     libQt5Sql5-postgresql
Recommends:     python3-Markdown
Recommends:     python3-Pygments
Recommends:     python3-Send2Trash
Recommends:     python3-asttokens
Recommends:     python3-chardet
Recommends:     python3-cx_Freeze
Recommends:     python3-doc
Recommends:     python3-docutils
Recommends:     python3-pyenchant
Recommends:     python3-pylint >= 0.18.0
Recommends:     python3-pysvn >= 1.7.0
Recommends:     python3-pyyaml
Recommends:     python3-rope >= 0.9.2
Recommends:     python3-toml
Provides:       python-eric5 = %{version}
Obsoletes:      python-eric5 < %{version}
Provides:       python-eric6 = %{version}
Obsoletes:      python-eric6 < %{version}
Provides:       eric5 = %{version}
Obsoletes:      eric5 < %{version}
Provides:       eric6 = %{version}
Obsoletes:      eric6 < %{version}
BuildArch:      noarch

%description
Eric is a Python and Ruby editor and IDE, written in Python. It is
based on the Qt GUI toolkit and integrates the Scintilla editor
control.

%package api
Summary:        API files for eric6
Group:          Development/Tools/IDE
Provides:       python-eric5-api = %{version}
Obsoletes:      python-eric5-api < %{version}
Provides:       python-eric6-api = %{version}
Obsoletes:      python-eric6-api < %{version}
Provides:       eric5-api = %{version}
Obsoletes:      eric5-api < %{version}
Provides:       eric6-api = %{version}
Obsoletes:      eric6-api < %{version}

%description api
This package provides API files for eric6.
If both python-eric6 and python3-eric6 packages are installed then only one
python-eric6-api or python3-eric6-api is needed.

%prep
%setup -q -n %{distname}-%{version}

find . -name \*.py -exec sed -i -e '/^#!\/usr\/bin.*python/d' '{}' \;

%build
# nothing here

%install
python3 install.py -b %{_bindir} -d %{python3_sitelib} -i %{buildroot} --no-tools --no-info
%fdupes %{buildroot}%{python3_sitelib}
ln -sf eric6 %{buildroot}%{_bindir}/%{name}

%files
%license eric/docs/LICENSE.GPL3
%doc eric/docs/README*.rst eric/docs/THANKS eric/docs/eric6-plugin.odt
%{_bindir}/*
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/%{distname}.appdata.xml
%{_datadir}/applications/%{distname}.desktop
%{_datadir}/applications/%{distname}_browser.desktop
%{_datadir}/icons/eric.png
%{_datadir}/icons/ericWeb.png
%{_datadir}/icons/hicolor/*/apps/eric.png
%{_datadir}/icons/hicolor/*/apps/ericWeb.png
%{python3_sitelib}/

%files api
%license eric/docs/LICENSE.GPL3
%dir %{_datadir}/qt5
%dir %{_datadir}/qt5/qsci/api/python
%{_datadir}/qt5/qsci/api/python/*
%dir %{_datadir}/qt5/qsci/api/ruby
%{_datadir}/qt5/qsci/api/ruby/*
%dir %{_datadir}/qt5/qsci/api/qss
%{_datadir}/qt5/qsci/api/qss/*

%changelog
* Sun Mar  6 2022 Hans-Peter Jansen <hpj@urpla.net>
- Add new EditorConfig dependency
- Add libQt5Sql5-sqlite dependency and recommends for mysql and
  postgresql plug-ins
- Add more recommends, according to install.py
* Sat Jan 15 2022 Dirk Müller <dmueller@suse.com>
- update to 21.11
  eric 21.11 has been released. It fixes just a few bugs. This will be the last
  release of the 'eric6' line of development (i.e. the one requiring PyQt5/Qt5 as
  its execution environment).
* Mon Oct 25 2021 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 21.9
  - bug fixes
  - MicroPython
  - - extended the list of known CircuitPython and UF2 capable
    devices
  - Unit Test
  - - added support for sub-tests
- Update to version 21.7
  - bug fixes
- Update to version 21.6
  - bug fixes
  - Tasks
  - - made the task properties dialog adapt to the task kind
  - - added code to get typed manual tasks
  - UML Diagrams
  - - extended the class items to show class attributes
  - - added code to load a saved UML diagram via the file browser
    or
    the project others browser
  - - improved the diagram layout of the Import Diagram and the
    Application Diagram
  - - added code to save and load diagrams as JSON files
  - - changed code to print diagrams
- Update to version 21.5
  - bug fixes
  - Code Style Checker
  - - added a checker to find code that could be simplified
  - - added capability to the results page to filter the messages
    based on
    message code
  - - improved the statistics handling
  - - updated pycodestyle to version 2.7.0
  - MicroPython
  - - added option to select the baud rate for flashing ESP32 and
    ESP8266 boards
  - - updated the BBC micro:bit API file to support micro:bit V2
  - Python Lexer
  - - updated the substyle contents
  - Syntax Checker
  - - updated pyflakes to version 2.3.1
  - Third Party packages
  - - removed most of the bundled Third Party packages in favour
    of pip
    installed packages
- Update to version 21.4
  - bug fixes
  - Code Style Checker
  - - added a checker to help porting to the 'pathlib' module
  - Debugger
  - - extended the Start... dialogs to allow to override some
    global
    configuration settings (redirect stdin/stdout/stderr)
  - Editor
  - - added capability to delete the matching brace if the cursor
    is
    in between them (e.g. {}) and backspace is pressed
  - Pip Interface
  - - added support for a re-installation of selected packages
  - Shell
  - - changed the shell special commands to start with a '%%' (e.g.
    %%start)
- Update to version 21.3
  - bug fixes
  - General
  - - changed the default file format for several generated files
    to be based on
    JSON
  - - added support for Cython
  - Debugger
  - - added capability to delete environment variables for the
    debugged script
    by adding a '-' to the variable name in the start dialog
  - Debug Viewer
  - - changed code to show project relative paths in the
    breakpoint viewer
  - Editor
  - - integrated the "Quick Search" functionality into the editor
    search widget
  - - added support for Cython to the code outline/navigation
    lists
  - - added support for Cython to the Typing Completers
  - File Browser
  - - added capability to show/hide hidden files (i.e. those
    starting with '.')
  - - added capability to create new files/directories and delete
    them
  - - added Cython support to show the file structure of these
    files
  - Mercurial Interface
  - - added support for Mercurial 5.7
  - MicroPython
  - - added support for "Raspberry Pi Pico" (i.e. RP2040 based
    boards)
  - - extended the list of supported (recognized) CircuitPython
    boards
  - - added capability to manually configure devices not yet known
    by eric6
  - - added a generic dialog for flashing UF2 capable devices
    (with device
    detection)
  - - added code to support 'middle button paste'
  - pip Interface
  - - changed code for the search function to work with the PyPI
    search page
    because the XML-RPC search interface of PyPI is still disabled
  - - extended the Package Details dialog to include buttons to
    install,
    upgrade or uninstall the package
- Update to version 21.2
  - bug fixes
  - General
  - - added support for PyQt6
  - - added support for PySide6
  - Code Style Checker
  - - added a commented code whitelist patterns to the
    Miscellaneous Checker
  - - added support for the '@yield' and '@ytype' tags
  - Debugger
  - - added support for debugging multiprocess scripts using these
    methods
  - -- QProcess.start(), QProcess.startDetached()
  - -- subprocess.Popen()
  - -- multiprocessing.Process()
  - -- os.spawnl...(), os.spawnv...(), os.posix_spawn...(),
    os.fork(),
    os.fork_exec()
  - -- _winapi.CreateProcess(), _subprocess.CreateProcess()
  - - added support for debugging code strings (-c, --code) or
    script modules
    (-m, --module)
  - - added support for the "Continue Until" action execution code
    until the
    current cursor line (if it is greater than the current line) or
    until
    returning from the current frame
  - Documentation Generator
  - - added support for the '@yield' and '@ytype' tags to document
    generators
  - Editor
  - - added code to enclose the current selection by entering ", '
    or a bracket
    ( (, ), [, ], {, }, <, > ) characters
  - - extended the exporters to support sub-styles
  - - added functionality to insert docstring templates via the
    context menu
    (cursor placed on first line of function definition), after
    entering
    the docstring start string (e.g. """ for Python) or via a
    keyboard
    shortcut (default: Ctrl+Alt+D) when cursor is either placed on
    the
    function definition line or after the end of the function
    definition
  - Find File Dialog
  - - added option to exclude hidden files and directories
  - - changed directory tree search logic to derive the file
    patterns from the
    project file type associations, if the directory to be searched
    is a
    sub-directory of the project
  - User Interface
  - - added capability to show Qt6 documentation (configurable)
  - VirtualEnv Manager
  - - improved the handling of virtual environments slightly
  - Web-Browser
  - - added an error page for not supported eric: URLs
  - Third Party packages
  - - updated eradicate.py to 2.0.0
  - - updated chardet to 4.0.0
  - - updated coverage.py to 5.3.1
  - - updated editorconfig to 0.12.3
  - - updated Pygments to 2.7.4
* Sat Jan  2 2021 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 21.1
  - bug fixes
- Update to version 20.12.1
  - bug fixes
- Update to version 20.12
  - bug fixes
- Update to version 20.11
  - bug fixes
  - Editor
  - - added support for TOML files
  - Main Window
  - - added a dialog showing information about the installation
    process
    (see Help menu)
  - Mini Editor
  - - added a status bar languages menu
  - - added a status bar zoom slider
  - - added zoom actions menu and toolbar
  - Syntax Checker
  - - added a syntax checker for TOML files
  - Web Browser
  - - added a SSL information page to the site info dialog
  - - added a clickable SSL info label to the URL entry
  - Various
  - - changed code to not use deprecated 'QRegExp' anymore
- Don't attempt to install/use pyqt5-tools/qt5-applications
- Don't create install info file
  rpmlint complains that this file contains buildroot
* Mon Oct  5 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 20.10
  - bug fixes
  - Editor
  - - added an outline widget showing the structure of the editor
    source code and allowing to navigate in the code
  - Python Disassembly Viewer
  - - added a tool to visualize the Python byte code generated
    from a Python source file
  - - added a viewer to visualize Python byte code generated from
    a Python traceback of an exception as an additional tab of
    the debug viewer
  - - added capability to show information about a code object
  - Third Party packages
  - - updated Pygments to 2.7.0
  - - updated coverage.py to 5.3.0
  - - removed th no longer needed 'enum' package
  - Various
  - - changed the code to not rely on the Qt Resource system
    anymore (no .qrc files and no use of pyrcc5 anymore)
- Update to version 20.9
  - bug fixes
  - File Browser
  - - changed it to react upon changed files if their contents is
    shown Tasks
  - - added separate task categories for 'Test' and
    'Documentation' tasks
  - Mercurial Interface
  - - removed the interface for the deprecated 'fetch' extension
  - VCS Interfaces
  - - added a configuration option to disable the VCS toolbars
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 20.8
  - bug fixes
  - removed support for Python2
  - removed support for Qt4 (PyQt4 and pyside)
  - - added menu action for pip cache management
  - - changed the dialog to allow the selection of checker categories
  - - added several security related checks (ported from bandit)
  - - extended the dialog to show a list of files still to be checked
  - - updated pycodestyle to version 2.6.0
  - - updated pyflakes to version 2.2.0
  - - updated asttoken to version 2.0.4
  - bug fixes
  - - added a configurable URL entry color to indicate sites with certificate
    issues
  - - added code to ask for the title of a new bookmark folder
  - - updated Pygments to 2.3.1
* Sat May  9 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 20.5:
  - MicroPython
  - - added support for Calliope mini
  - Third Party packages
  - - updated Pygments to 2.3.1
* Sun Apr  5 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 20.4:
  - bug fixes
  - General
  - - included a new icon set based on the Breeze icons of KDE
* Sat Mar 14 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 20.3:
  - bug fixes
  - Debugger
  - - added debugging support for QRunable
  - Mercurial Interface
  - - added support for the '--secure' flag of hg import as of
    Mercurial 5.3
  - Syntax Checker
  - - updated pyflakes to repository as of 2020-02-03
  - Third Party packages
  - - updated coverage.py to 5.0.3
* Mon Feb  3 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 20.2:
  - bug fixes
  - remove source URL workaround (fixed upstream)
* Sun Jan 26 2020 Hans-Peter Jansen <hpj@urpla.net>
- fix source URL
* Sun Jan 26 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 20.1:
  - bug fixes
  - MicroPython
  - - added entries to the ESP menu to show the Chip ID, Flash ID and
    MAC Address
  - - added entries to the ESP menu to backup and restore a firmware
  - Web Browser
  - - added support for viewing PDF documents inside the web browser
    (requires PyQt/Qt 5.13 or better)
* Sun Dec  8 2019 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 19.12
  - bug fixes
  - MicroPython
  - added a menu entry to show the local and device time side-by-side
  - added a PyBoard menu entry to flash a new firmware
  - added a menu entry to open the firmware download page of a device
  - Syntax Checker
  - added a syntax checker for JSON files
  - added a syntax checker for YAML files
  - install script
  - added the "--yes" flag to allow installation of all missing
    prerequisites with pip without asking
- removed the patches
  * eric-focus-issues-fix.patch
  * eric-more-fixes.patch
* Thu Dec  5 2019 Hans-Peter Jansen <hpj@urpla.net>
- add another patch to fix more issues
  * eric-more-fixes.patch
* Sun Dec  1 2019 Hans-Peter Jansen <hpj@urpla.net>
- add patch to fix two focus related issues
  * eric-focus-issues-fix.patch
* Thu Nov 28 2019 Hans-Peter Jansen <hpj@urpla.net>
- Add python-Markdown recommendation (for *.md files preview)
- Fix a small glitch with sed
* Wed Nov 13 2019 Hans-Peter Jansen <hpj@urpla.net>
- Fix source path
* Tue Nov 12 2019 Hans-Peter Jansen <hpj@urpla.net>
- Clean up spec file
* Tue Nov  5 2019 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 19.11
  - bug fixes
  - Editor
  - extended the spell checking functionality for all text files
  - added a context menu to select spell check language
  - made the preview refresh timeout configurable
    (see Editor -> File Handling config page)
  - Error Message Dialog:
  - added a configurable minimum severity for messages being
    shown in a dialog (see Application config page)
  - MicroPython
  - added support for PyBoard
  - Previewers
  - enhanced the Markdown previewer by using the PyMdown
    extensions, if they are available and have been enabled
  - enhanced the Markdown previewer to support MathJax, if it
    has been enabled
  - enhanced the Markdown previewer to support Mermaid via the
    md_mermaid extension, if it is available and has been enabled
- Update to version 19.10
  - bug fixes
  - removed runtime support for Python2 and PyQt4
  - changed minimum Qt/PyQt version required to 5.9.0
  - Code Style Checker
  - added more comprehension checks
  - added checks for insecure use of sys.version and
    sys.version_info
  - added a checker class for type annotations
  - Editor
  - added configuration option to set the tab and indentation
    width for each languages separately (as an override to the global
    ones)
  - added a typing aid for YAML
  - QFileDialog Wizard:
  - added support for the QFileDialog.get...Url() methods
  - added support for E5FileDialog
  - Third Party packages
  - updated coverage.py to 4.5.4
- Remove PyQt4 support from spec
- Enable dependency checks
* Mon Sep  9 2019 Hans-Peter Jansen <hpj@urpla.net>
- fix URL
* Sat Sep  7 2019 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 19.9
  + bug fixes
  + added widgets to support development for embedded controllers
    with MicroPython (ESP8266/ESP32, CircuitPython and BBC micro:bit)
  + Main Window
    + added an action to the Windows menu to activate the current
    editor
  + Mercurial Interface
    + added an action to commit a merge
  + Web Browser (NG)
    + added support for the QWebEnginePage.Notifications as Qt 5.13.0
  + API Files
    + added API files for BBC micro:bit MicroPython and updated
    the PyQt5 API files
  + API Generator
    + added the -i switch to ignore the existence of builtin modules
    when creating API files
- Update to version 19.8
  + bug fixes
  + Third Party packages
    + upgraded pyflakes to version 2.1.1 plus repository changes
    to fix some issues (until 2019-07-09)
- Update to version 19.7
  + bug fixes
  + Code Style Checker
    + added check for commented code that should be removed
    + added check for line continuation methods not suggested by PEP-8
    + added checks for naive uses of datetime classes
- Update to version 19.6
  + bug fixes
  + Code Style Checker
    + added checks for use of 'gettattr' and 'setattr', base super()
    calls and 'assert False' statements
  + Editor
    + Python Typing
    + added support for 'from ... import (...)'
    + changed the indentation when the previous line ends with
    '(', '[' or '{'
    + Ruby Typing
    + changed the indentation when the previous line ends with
    '(', '[' or '{'
  + Mercurial Interface
    + extended the log browser to start with showing all incoming
    and the first batch of local changesets
    + show different icons for incoming, outgoing and normal
    changesets
    + added capability to search and filter based on the changeset
    phase
    + added support for the 'closehead' extension (as of Mercurial
    4.8)
    + added support for the '--keep' flag of the shelve command
    (as of Mercurial 5.0)
  + Shell
    + added capability to place the Shell window in the left or
    right side container
  + setup.py Wizard
    + updated the Trove classifiers list
    + added capability to retrieve the Trove classifiers list from
    PyPI
  + Variables Viewer
    + reimplemented Variables Viewer using QTreeView with
    unlimited access to big arrays, dicts, etc. because elements
    are lazy loaded
    + highlighting of still unloaded (default: yellow background)
    and last
  + changed variable(s) (default: green background)
    + colors for highlighting are configurable through
    Debugger->General
    + expand / collapse variables with children on double click on
    first column,
  + in all other cases display detail window
    + handling of dict views improved (can be expanded like lists)
    + show tooltips on all elements which don't fit into current
    column width
    + new options in the context menu, e.g. expand / collapse all
    child nodes
  + Third Party packages
    + updated EditorConfig to 0.12.2
- Update to version 19.5
  + bug fixes
  + General
    + added functionality to provide eric6 via PyPI. Installation
    can be accomplished via 'pip install eric-ide'
  + Python AST Viewer
    + added a tool to visualize the AST for a Python source file
  + Snapshot Tool
    + added code to support screenshots on Wayland desktops (KDE
    and Gnome)
- Deal with relocated docs
* Sun Apr  7 2019 seanlew@opensuse.org
- Update to 19.04
  * added a checker for advised forms of the return statement
  * addd extended regex support for C++ 11
  * added capability to configure the subline indent
  * added capability to frame the line containing the cursor
  * added support for sub-styling
  * extended support for keyword sets
* Sun Mar  3 2019 seanlew@opensuse.org
- Update to 19.03
  * added an interface for the conda environment/pkg management
  * suppress auto-completions in various circumstances
  * changed the if from menu based -> widget-based in toolbox
  * extended the environment def by a flag indicting remote access
  * updated pycodestyle to 2.5.0
  * updated pyflakes to 2.1.0
* Mon Feb 18 2019 seanlew@opensuse.org
- Update to 19.02
  * added capability to suppress some markers in the marker map
  * add capability to the multi project browser to remove a project
  * added support to select a client SSL Cert (Qt 5.12)
* Fri Jan 11 2019 seanlew@opensuse.org
- Update to 19.01
  * added entry to select the virt environment of the current proj
  * added support for some resource compiler options
  * added single application mode
  * change logic inside eric to use a browser to show help text
* Sat Dec 29 2018 sean@suspend.net
- Update to 18.12:
  * changed the 'regexp' search option to use POSIX mode
  * added the ability to search for a regex
  * added support for the resource-suffix and --import-from= opts
  * added a button to open the translator config page
  * extended the env definition by a flag indicating an Anaconda env
  * changed the start menu to give a list of defined envs
* Fri Nov  2 2018 sean@suspend.net
- Update to 18.11:
  - IRC
  - -  added support for some of the "/" commands to the user context menu
  - Translator
  - - changed DeepL support to DeepL Pro
  - VCS
  - - added capability to show some VCS information in the main status window
* Tue Oct 23 2018 Hans-Peter Jansen <hpj@urpla.net>
- Update to 18.10:
  - General
  - - changed the extension of the generated script files for Windows
    from '.bat' to '.cmd'
  - Debugger
  - - added code to use the default virtual environment, if none has
    been configured yet
  - IRC
  - - added support for the /query, /notice, /ping, /ignore, /unignore,
    /away, /join, /part and /partall commands
  - Tasks
  - - added code to mark a line as not containing a task with '__NO-TASK__'
* Wed Sep 12 2018 Hans-Peter Jansen <hpj@urpla.net>
- Update to 18.09:
  - bug fixes
  - Mercurial Interface
  - - added support for Mercurial 4.7 extended commands 'graft', 'rebase' and
    'export'
* Fri Aug  3 2018 hpj@urpla.net
- Update to 18.08:
  - bug fixes
  - General
  - - made the activation of these internal tools configurable
  * Template-Viewer
  * File-Browser
  * Symbols
  * Code Documentation Viewer
  * Cooperation
  * IRC
  * Numbers
  - File-Browser
  - - changed code so file-browser is always a standalone window
  - Project Interfaces Browser
  - - added actions to configure some IDL compiler options (-I, -D, -U)
  - Shell
  - - changed code so shell is always a standalone window
  - Translator
  - - added a translation engine for the IBM Watson Language Translator
  - Web Browser (NG)
  - - added default search engine definitions for
  * Qwant
  * StartPage
- Update to 18.07:
  - bug fixes
  - Checkers
  - - upgraded pyflakes to version 2.0.0
  - Debugger
  - - added support of breakpoint() builtin of Python 3.7
  - - added code to try to open the source file if an exception occurred in
    a cython .pyd file
  - Git Interface
  - - added capability to change the URL and/or user credentials for a
    remote repository
  - pip Interface
  - - added support for the '--user' option of install and list commands
  - - changed to use the new VirtualEnv Manager
  - Unit Test
  - - extended the standalone unit test tool to be able to open source in an
    editor window
  - VirtualEnv Manager
  - - added a manager for virtual environments
  - - changed a few places to use the newly introduced virtual environments
    (Note: a new session file format and debug properties file format
  has been introduced)
* Thu Jun  7 2018 hpj@urpla.net
- fix api requires/obsoletes
* Mon Jun  4 2018 hpj@urpla.net
- Update to 18.06:
  - bug fixes
  - Editor
  - - added a configuration option (Editor->Style page) to show the marker map
    on the left or right of the editor
  - - added a context menu for the "fold" margin
  - - improved handling of folded lines when using "go to" functions
  - - resize auto complete list box to fit with contents
  - - added a configuration option (Editor->autocomplete to set up maximum
    width and height of the auto complete list box
  - Shell
  - - resize auto complete list box to fit with contents
  - pip Interface
  - - added an action to install a locally available package/wheel
  - Web Browser (NG)
  - - improved the sending of the "Referer" header like it is done by Firefox
- remove eric-fix-bindir.patch: desktop files install fix is released from
  upstream
* Sun May 27 2018 hpj@urpla.net
- Use build conditionals to select qt version
- Further spec file cleanup
- Fix eric-api recommendation
* Thu May 24 2018 mcepl@suse.com
- Rename files from eric6 to eric, when applicable
- Build with Qt4 on LEAP 42.3
* Mon May 21 2018 hpj@urpla.net
- fix requires/obsoletes
- cleanup spec
* Fri May  4 2018 hpj@urpla.net
- use upstream fix for desktop files
* Tue May  1 2018 hpj@urpla.net
- Update to 18.05:
  - bug fixes
  - General
  - - added the '--disable-plugin=' option to disable plug-ins via the command
    line
  - Code Style Checker
  - - added support for '# noqa' and '# NOQA' comments to suppress warnings
  - - extended the dialog to be able to define the number of blank lines
    before class and function/method definitions
  - Project
  - - added support for 'make' to the Project menu and run it automatically
    before the main script is started (configuration option)
  - Syntax Checker
  - - added support for '# noqa' and '# NOQA' comments to suppress warnings
  - Translator
  - - updated the translator URL for DeepL
  - Web Browser (NG)
  - - improvement of the download manager
  - - added support for the Google Safe Browsing Lookup API (v4)
  - Third Party packages
  - - updated coverage.py to 4.5.1
  - - updated pycodestyle to 2.4.0
  - - updated send2trash to version 1.5.0
- Fix desktop files executable path
* Mon Apr 30 2018 hpj@urpla.net
- Update to 18.04:
  - bug fixes
  - General
  - - added config option to disable the use of the global menu bar on Linux
    Code Style Checker
  - - added checks for default docstring in functions and modules
  - - added check for dictionaries with sorted keys
  - - added checks for logging statements
  - - added check for the 'gettext' import statement
  - - added some checks of the bugbear checker
- Update to 18.03:
  - bug fixes
  - Editor
  - - added support for EditorConfig
  - - added VCS conflict markers to the types shown on the marker map
- Update to 18.02:
  - bug fixes
  - General
  - - extended the session to store/retrieve the split views and the order of
    the editors (Note: The new session file format is not backward compatible
    and cannot be read by eric releases prior to 18.02)
  - - added basic support for Cython
  - Editor
  - - added a context menu entry to "Execute Selection In Console"
  - Web Browser (NG)
  - - added support for HTML5 "Desktop Video Capture" and "Desktop Audio and
    Video Capture" as of Qt 5.10.0/PyQt 5.10.0
  - - added the capability to pause/resume download (Qt 5.10.0/PyQt 5.10.0)
  - - added support for attributes introduced by Qt 5.9 and Qt 5.10
- Rename package to eric6
* Sat Jan  6 2018 termim@gmail.com
- Update to 18.01:
  - bug fixes
  - Debugger / Breakpoint Viewer
  - - added the capability to remember the most recently used file names and
    conditions
  - Editor
  - - added an action to the view menu to clear all folds of the current editor
  - - added an entry to delete all change markers to the marker margin context
    menu
  - Project
  - - If a project does not contain protobuf files, the old project file format
    (5.1) is generated to make the file backward compatible.
  - Plug-ins
  - - added the pip interface plug-in to the core plug-ins
  - - added the virtualenv/pyvenv interface plug-in to the core plug-ins
  - - added the setup.py wizard plug-in to the core plug-ins
  - - added the eric plug-in wizard plug-in to the core plug-ins
  - - added the .desktop wizard plug-in to the core plug-ins
  - - added the translator plug-in to the core plug-ins
  - - added the git plug-in to the core plug-ins
  * *Note**: These plug-ins should be deinstalled via the plug-in
  uninstallation dialog of eric before upgrading eric. A reconfiguration of
  these plug-ins may be neccessary.
  - PluginToolPip
  - PluginWizardVirtualenv
* Thu Jan  4 2018 termim@gmail.com
- fix rpm build
* Tue Dec 26 2017 jengelh@inai.de
- Remove marketing from description.
* Fri Dec  8 2017 fabian@ritter-vogt.de
- Use PyQt5
- Drop python3-sip requires, python-qt5 already requires it
- Run spec-cleaner
- Use full URL for Source:
* Tue Dec  5 2017 termim@gmail.com
- Update to 17.12:
  - bug fixes
  - General
  - - added support for Google protobuf protocol files
  - Code Documentation Viewer
  - - added possibility to show the type of the object info is shown for
  - - modified the top row and the search part in order to allow smaller sizes
  - Debugger / Variables Viewer
  - - introduced a configuration option to limit the variables shown by the
    variables viewers depending on their size (in order to avoid overload
    situations on low power or low memory machines)
  - Styles
  - - added a dark style (*.qss and Python lexers) provided by Giuseppe
    Corbelli
  - Third Party packages
  - - updated send2trash to version 1.4.2
  * *NOTE**: This release introduces a new project file format that will be
    rejected by previous releases. The new format is needed for the Google
    protobuf support.
* Sun Nov 19 2017 termim@gmail.com
- Update to 17.11.1
  - Bug fixes
* Fri Nov  3 2017 termim@gmail.com
- Update to 17.11
  - Debugger:
  - added capability to enter an interpreter in the Start... dialog
  - Editor
  - added support for auto-completion lists being provided asynchronously
  - added a viewer for source code documentation extracted by providers
    to be implemented by plug-ins (like rope and jedi)
  - Web Browser (old style)
  - changed logic in order to put new downloads at the top of the list of
    downloads and added the download date and time to the shown info
  - Web Browser (NG)
  - changed logic in order to put new downloads at the top of the list of
    downloads and added the download date and time to the shown info
* Mon Oct  9 2017 termim@gmail.com
- Update to 17.10
  - bug fixes
  - Web Browser (NG)
  - added a downloader and installer/uninstaller dialog for spell check
    dictionaries
* Fri Sep  1 2017 termim@gmail.com
- Update to 17.09
  - bug fixes
  - Debugger
  - -  unified the Python2 and Python3 debugger interfaces
  - Exporter
  - - extended the HTML exporter to convert Markdown and ReST files to
    HTML
  - Plugin Manager
  - - added a bar with counts for new/local updates/remote updates to the
    plug-in repository dialog
  - Previewers
  - - added capability to configure the output format for the markdown
    and docutils (ReST) previewers
  - Web Browser (NG)
  - - added support for Google Safe Browsing
  - Third Party packages
  - - updated jasy to 1.5-beta5 (latest release available)
- remove i18 tarballs - they are already in the main archive.
* Fri Aug  4 2017 termim@gmail.com
- Update to 17.08
  - bug fixes
  - Shell
  - - added support for different history navigation styles (disabled,
    Linux, Windows)
  - - improved shell history dialog
  - Templates
  - added some new predefined template variables (time, path_name_rel,
    dir_name_rel)
  - Web Browser (NG)
  - - added support for sessions
* Sun Jul  2 2017 termim@gmail.com
- Update to 17.07
  - Background Services
  - - added functionality to limit the number of processes used for
    background services
  - Bug Reporting / Feature Request (Email)
  - - added the capability to send these emails via Google Mail using
    OAuth2 authentication
  - Diff Dialogs
  - -  made the colors of the diff dialogs configurable
  - Third Party packages
  - - updated chardet to 3.0.4
- Update to 17.06
  - bug fixes
  - Checkers
  - - extended the source documentation checker to check for raised/documented
    exceptions and defined/documented signals
  - Editor
  - - reintroduced the highlighting of current instruction line and the error
    line using colored background. It is configurable whether to use these
    backgrounds or the arrows.
  - - added capability to perform the various replace methods via keyboard
    shortcuts
  - Plugin Manager
  - - added an option to cleanup the plug-ins download area during startup
  - Qt Tools
  - - added code to auto-discover the presence of the new 'pyqt5-tools' wheel
    (Windows only) (thanks to Kyle Altendorf for providing this wheel)
  - Web Browser (NG)
  - - united the stop and reload buttons of the navigation bar
  - - added a super menu to modernize the look & feel
  - - added Ctrl-Click and middle click actions to the navigation buttons
    to perform the action in a new tab
* Sat May  6 2017 termim@gmail.com
- Update to 17.05
  - bug fixes
  - Editor
  - - changed the indication of the current instruction line and the error line
    to use a green or red arrow instead of a colored background
  - PyQt Tools
  - - added a configuration option for the path of the PyQt tools
  - Shell
  - - added a standalone shell window
  - Web Browser (NG)
  - - added the last visited time and date to the bookmark properties dialog
  - - added a visit count to the history entries (shown in the history dialog)
  - - made full screen mode really full screen
  - Third Party packages
  - - updated Pygments to 2.2.0
  - - updated chardet to 3.0.2
* Tue Apr 11 2017 termim@gmail.com
- Update to 17.04.1
  - - bug fixes
- Update to 17.04
  - bug fixes
  - General
  - - increased minimum required Python versions to prevent usage
    with very old versions (i.e. eric was never tested with)
    min. versions: Python 2 - 2.7.10; Python 3 - 3.4.0
  - Checkers
  - - added checks for shadowed Python builtins and unneccessary comprehensions
    and generators to the code style checker
  - - added a checker to check for lines of code of too high complexity
  - - added capability to place line flags (e.g. __IGNORE...) on the line
    following the one to be ignored
  - Debugger
  - - shell autocompleter takes the right global variables into account now
  - - move the instruction pointer within the current function (Hotkey: F12)
  - - report syntax and indentation errors raised by an application or module
    in the correct manner
  - - avoid crashes on using greenlets
  - Mercurial Interface
  - - extended the user configuration dialog
  - - added support for the 'zstd' compression for bundles (as of 4.1.0)
- add fetch script fetch-eric.sh
* Sat Mar 11 2017 termim@gmail.com
- Update to 17.03.1
  - bug fixes
* Fri Mar  3 2017 termim@gmail.com
- Update to 17.03
  - Checkers
  - - upgraded pycodestyle to version 2.3.1
  - - upgraded pyflakes to version 1.5.0
  - Debugger
  - - prevent stepping into print statements if checkbox for debugging into
    interpreter libraries is checked
  - - catch unhandled exceptions again
  - - support for PySide2 added
  - - atexit handling works as specified in any condition
  - - prevent ordinary breakpoints to steal the focus from an exception
  - Mercurial Interface
  - - improved the log browser in several ways
  - - improved the status dialog
  - Project
  - - added capability to remember previously used entries in the project
    debugger properties dialog
  - Web Browser (NG)
  - - added support for new options provided by Qt 5.8.0
  - - added support for spell checking as of Qt 5.8.0
* Sun Feb  5 2017 termim@gmail.com
- Update to 17.02.1
  - fixes a regression related to using eric with Qt 4.8.
- Update to 17.02
  - Checkers
  - - upgraded pycodestyle to version 2.2.0+
  - Debugger
  - - changed the variables filter dialog to be more user friendly
  - Editor
  - - added a bar with formatting options for HTML, Markdown and reStructured
    Text files
  - - added support for the new QScintilla JSON lexer
  - - added support for the new QScintilla Markdown lexer
  - Email
  - - added capability to use the SSL encryption method (next to StartTLS) in
    the built in Email dialog
  - Mercurial Interface
  - - added clickable links to the log browser details pane
  - - added up and down buttons to move the current entry to the log browser
  - - added the capability to configure the length of the log message shown
    in the message column of the log browser list
  - Subversion interface
  - - added up and down buttons to move the current entry to the log browser
  - Web Browser
  - - added functionality to manage the plug-in provided documentation sets
* Tue Jan  3 2017 termim@gmail.com
- Update to 17.01
  - bug fixes
  - General
  - - added capability to save a global session to disk and restore it
  - - added capability to save a crash session in order to restore the
    current state in case of a cras
  - - added option to configure the crash session startup behavior and
    added the '--no-crash' option to suppress looking for a crash session
  - - added the '--disable-crash' option to temporarily disable the crash
    session support through the command line
  - - changed some options: --noopen to --no-open, --nosplash to --no-splash
  - Debugger
  - - added capability to edit the history lists of the start dialogs of
    the debugger
  - Editor
  - - added support for project type specific auto-completion and
    calltips including the respective configuration (Editor->APIs page)
* Sat Dec  3 2016 termim@gmail.com
- Update to 16.12
  - Mercurial Interface
  - - added context menu actions to the tags/branches list dialog
  - - added bookmark actions to the Log Browser tools menu
  - - added context menu actions to the bookmark list dialog
  - - added possibility to enter a commit author and commit date/time
  - - added capability to enforce a tagging operation
  - Third Party packages
  - - updated chardet to 2.3.0
* Sun Nov 13 2016 termim@gmail.com
- Update to 16.11
  - bug fixes
  - General
  - - added a status bar icon to show the online status to the main window
  - - added an action to clear the private data of the IDE
  - Checkers
  - - added capaibility to ignore warnings by code (use
    __IGNORE_WARNING_<code>__, e.g. __IGNORE_WARNING_M613__)
  - Debugger
  - - added a debugger interface registry to allow debuggers being
    implemented as plug-ins
  - - Python Debuggers:
  - -- changed the protocol to a JSONRPC style protocol to be more robust
  - -- massive speed gain of the debug client (Tobias Rzepka)
  - -- unified the debugger clients for Python 2 and 3 (Tobias Rzepka)
  - -- unified the standard and threaded debugger clients (Tobias Rzepka)
  - -- added debug support for QThread threads (Tobias Rzepka)
  - - Ruby Debugger:
  - -- removed the Ruby debugger (the interface doesn't work with recent
    Ruby versions anymore)
  - - Call Trace Viewer
  - -- added capability to stop recording upon exit of the client script
  - - Variables Viewer
  - -- added capability to refresh the view via the context menu
  - Hex Editor
  - - added a nice little hex editor tool (usable as a standalone tool
    as well)
  - Icon Editor
  - - added capability to close all other icon editor windows
  - Project
  - - added a dialog to quickly search for files in the list of project files
    (thanks to Mike C. Fletcher for contributing the majority of this)
  - - added an option to rescan the project for tasks upon open
  - Project Browser
  - - added capability to search the file tree via the keyboard (directories and
    files only)
  - Tools
  - - Tray Starter
  - -- added an entry to show the version information
  - Version Control System Interfaces
  - - Mercurial
  - -- added support for pulling and pushing the current bookmark
  - -- added support for the strip extension
  - -- added support for the histedit extension
  - -- added support for the strip and fetch extensions to the log browser
  - -- added an action to the administration menu to clean out the backup
    bundles
  - Web Browser
  - - added capability to remember the zoom values for each site (incl. a
    dialog to manage these)
  - - added a status bar icon to show the online status
  - Web Browser (NG)
  - - ported the web browser to QtWebEngine as of Qt 5.6.0 because starting
    with this version QtWebKit is no longer (officially) supported
  - Third Party packages
  - - updated Pygments to 2.1.3
  - - updated pep8 to 2.1.0dev0 and renamed it to pycodestyle
  - - updated coverage.py to 4.1.0
  - - updated pyflakes to 1.2.3+
* Sun Nov  6 2016 termim@gmail.com
- Update to 6.1.11
  * bug fixes
* Sun Oct  9 2016 termim@gmail.com
- Update to 6.1.10
  * bug fixes
* Sun Sep  4 2016 termim@gmail.com
- Update to 6.1.9
  * bug fixes
* Sun Jul 31 2016 termim@gmail.com
- Update to 6.1.8
  * bug fixes
  * improves compatibility with PyQt5 5.7.0 and above
* Mon Jul  4 2016 termim@gmail.com
- Update to 6.1.7
  * bug fixes
* Sun Jun  5 2016 termim@gmail.com
- Update to 6.1.6
  * bug fixes
* Mon May  9 2016 termim@gmail.com
- Update to 6.1.5
  * bug fixes
  * improved Py2/3 compatibility thanks to Parsifal Herzog
* Wed Apr 13 2016 termim@gmail.com
- Update to 6.1.4
  * bug fixes
* Wed Mar  9 2016 termim@gmail.com
- Update to 6.1.3
  * bug fixes
* Mon Feb  8 2016 termim@gmail.com
- Update to 6.1.2
  * bug fixes
* Thu Jan  7 2016 termim@gmail.com
- Update to 6.1.1
  * bug fixes
* Sat Dec  5 2015 termim@gmail.com
- Update to 6.1.0
- General
  * added a configuration page to edit the list of mime types to
    be opened in an eric editor
  * added the '--settings=' command line switch to store the
    settings files in a non-standard directory
- Checkers
  * added a batch mode to the code style checker to make use of
    multiple CPUs/CPU-Cores
  * added a batch mode to the syntax checker to make use of
    multiple CPUs/CPU-Cores
  * added a batch mode to the indentation checker to make use of
    multiple CPUs/CPU-Cores
  * added a code complexity checker iaw. McCabe to the code style
    checker
  * added miscellaneous checks to the code style checker (coding
    comment, copyright, blind except, print statements, one element
    tuples, __future__ imports, old style string formats, string
    format strings)
- Debugger
  * added signal handlers for the Python debug clients
- Editor
  * added capability to configure the indentation guides colors
  * added capability to ask multiple completion list and call-tip
    providers
  * added support for mouse click handlers to be provided by plug-ins
  * added the search markers to the marker map
  * added capability to save a copy of the editor contents
  * Lexers
  - added support for the new C++ lexer properties (as of
    QScintilla V. 2.9.0)
- File Browser
  * added capability to show imports of a Python script
- Log Viewer
  * added a message filter including a configuration page
- Mini Editor
  * added capability to save a copy of the editor contents
- Preferences Dialog
  * changed the 'filter' function to a 'search' function disabling
    all entries, that don't contain the entered string
  * changed the handling of the configuration page list entries
    to be collapsed on first show and remember the expanded ones
    while eric is running (but not between invocations)
- Previewers
  * added capability to use 'Sphinx' to preview ReST files
- Project
  * added functionality to reorganize the files automatically,
    when the project type or file type associations are changed
- Project Browser
  * added capability to show imports of a Python script
- Source Code Documentor
  * added tags to describe the type of parameters (@type, @ptype)
    and return values (@rtype)
- Task Viewer
  * added capability to add sub-tasks (i.e. a task hierarchy) for
    manually generated tasks
- Tools
  * Diff Dialog
  - added capability to search in the output
- Version Control System Interfaces
  * All
  - added capability to search in the output of Diff dialogs
  * Mercurial
  - enhanced the log browser functionality by a search mode
  - enhanced the log browser functionality by pull and push actions
  - enhanced the status dialog functionality by a diff view
- Web Browser
  * added support for HTML5 feature permissions
  * improved parsing of the content disposition header analog to
    the way it is done in qutebrowser
  * modified and extended the VirusTotal interface for the v2 API
  * added our own web inspector window to overcome a Qt weekness
  * added a manager for Flash Cookies
- Third Party packages
  * updated coverage to 4.0
  * updated Pygments to 2.0.2
* Tue Nov 10 2015 termim@gmail.com
- Update to 6.0.11
  * bug fixes
* Wed Oct 21 2015 termim@gmail.com
- Update to 6.0.10
  * bug fixes
* Wed Sep  9 2015 termim@gmail.com
- Update to 6.0.9
  * bug fixes
* Fri Aug 14 2015 termim@gmail.com
- Update to 6.0.8
  * bug fixes
  * compatibility to PyQt 5.5
* Mon Jul  6 2015 termim@gmail.com
-  Update to 6.0.7
  * bug fixes
* Thu Jun 11 2015 termim@gmail.com
- Update to 6.0.6
  * bug fixes
* Tue May 12 2015 termim@gmail.com
- Update to 6.0.5
  * bug fixes
* Mon Apr 13 2015 termim@gmail.com
- Update to 6.0.4
  * bug fixes
* Mon Mar  2 2015 termim@gmail.com
-  Update to 6.0.3
  * bug fixes
* Fri Feb 20 2015 termim@gmail.com
- Update to 6.0.2
  * bug fixes
* Sun Jan 18 2015 termim@gmail.com
- Update to 6.0.1
  * bug fixes
* Mon Dec 29 2014 termim@gmail.com
- Initial checkin
